.. :changelog:

History
-------

0.2.0 (2015-11-29)
---------------------

* Allow for node bootstrapping via SSH
* Push SSH public key
* Update Linux packages
* Install Docker
* Provide an inventory of running nodes
* Build inventory for ansible
* Extension mechanism called polishers
* Add demonstration scripts related to polishers
* A lot of docstring has been added
* fake8 complains only about long lines and line termination
* Passing Travis CI
* Test coverage 59%

0.1.2 (2015-11-27)
---------------------

* First pull request fully processed
* Docstring for all modules
* Passing Travis CI
* Test coverage 62%

0.1.1 (2015-11-23)
---------------------

* Minor modifications

0.1.0 (2015-11-20)
---------------------

* First release on PyPI.
